Function fuzz_calldata_from_state
pub fn fuzz_calldata_from_state<S>(
func: Function,
state: &S,
) -> impl Strategy<Value = Bytes> + use<S>where
S: FuzzStateReader,Expand description
Given a function and some state, it returns a strategy which generated valid calldata for the given function’s input types, based on state taken from the EVM.